@@ -181,7 +181,8 @@ class EventManager:
             return True
 
         script = orca_state.activeScript
-        if event.type.startswith('object:children-changed'):
+        if event.type.startswith('object:children-changed') \
+           or event.type.startswith('object:state-changed:sensitive'):
             if not script:
                 msg = 'EVENT MANAGER: Ignoring because there is no active script'
                 debug.println(debug.LEVEL_INFO, msg, True)
@@ -258,6 +259,11 @@ class EventManager:
                 msg = 'EVENT MANAGER: Ignoring event type due to role'
                 debug.println(debug.LEVEL_INFO, msg, True)
                 return True
+        elif event.type.startswith('object:state-changed:selected'):
+            if not event.detail1 and role in [pyatspi.ROLE_PUSH_BUTTON]:
+                msg = 'EVENT MANAGER: Ignoring event type due to role and detail1'
+                debug.println(debug.LEVEL_INFO, msg, True)
+                return True
         elif event.type.startswith('object:state-changed:showing'):
             if role not in [pyatspi.ROLE_ALERT,
                             pyatspi.ROLE_ANIMATION,
@@ -271,6 +277,21 @@ class EventManager:
                 msg = 'EVENT MANAGER: Ignoring event type due to role'
                 debug.println(debug.LEVEL_INFO, msg, True)
                 return True
+            if role == pyatspi.ROLE_PANEL:
+                if not event.detail1:
+                    msg = 'EVENT MANAGER: Ignoring event type due to role and detail1'
+                    debug.println(debug.LEVEL_INFO, msg, True)
+                    return True
+                try:
+                    if not event.source.name:
+                        msg = 'EVENT MANAGER: Ignoring event type due to role and lack of name'
+                        debug.println(debug.LEVEL_INFO, msg, True)
+                        return True
+                except:
+                    msg = 'EVENT MANAGER: Ignoring event from dead source'
+                    debug.println(debug.LEVEL_INFO, msg, True)
+                    return True
+
         elif event.type.startswith('object:selection-changed'):
             if event.source in self._parentsOfDefunctDescendants:
                 msg = 'EVENT MANAGER: Ignoring event from parent of defunct descendants'
@@ -346,6 +367,14 @@ class EventManager:
                 debug.println(debug.LEVEL_INFO, msg, True)
                 return True
 
+            # In normal apps we would have caught this from the parent role.
+            # But gnome-shell has panel parents adding/removing menu items.
+            if event.type.startswith('object:children-changed'):
+                if childRole == pyatspi.ROLE_MENU_ITEM:
+                    msg = 'EVENT MANAGER: Ignoring event type due to child role'
+                    debug.println(debug.LEVEL_INFO, msg, True)
+                    return True
+
         msg = 'EVENT MANAGER: Not ignoring due to lack of cause'
         debug.println(debug.LEVEL_INFO, msg, True)
         return False
@@ -446,8 +475,9 @@ class EventManager:
                 toolkitName = app.toolkitName
             except:
                 toolkitName = None
-            if toolkitName in self._synchronousToolkits \
-               or isinstance(e, input_event.MouseButtonEvent):
+            if isinstance(e, input_event.MouseButtonEvent):
+                asyncMode = True
+            elif toolkitName in self._synchronousToolkits:
                 asyncMode = False
             elif e.type.startswith("object:children-changed"):
                 try:
@@ -678,7 +708,7 @@ class EventManager:
         """Returns the script associated with event."""
 
         if event.type.startswith("mouse:"):
-            return orca_state.activeScript
+            return _scriptManager.getScriptForMouseButtonEvent(event)
 
         script = None
         app = None
@@ -740,9 +770,8 @@ class EventManager:
         
         if not script:
             script = self._getScriptForEvent(event)
-
-        if not script:
-            return False, "There is no script for this event."
+            if not script:
+                return False, "There is no script for this event."
 
         if script == orca_state.activeScript:
             return False, "The script for this event is already active."
@@ -785,9 +814,22 @@ class EventManager:
 
         return False, "No reason found to activate a different script."
 
+    def _eventSourceIsDead(self, event):
+        try:
+            name = event.source.name
+        except:
+            msg = "EVENT MANAGER: source of %s is dead" % event.type
+            debug.println(debug.LEVEL_INFO, msg, True)
+            return True
+
+        return False
+
     def _ignoreDuringDeluge(self, event):
         """Returns true if this event should be ignored during a deluge."""
 
+        if self._eventSourceIsDead(event):
+            return True
+
         ignore = ["object:text-changed:delete",
                   "object:text-changed:insert",
                   "object:text-changed:delete:system",
@@ -817,6 +859,9 @@ class EventManager:
     def _processDuringFlood(self, event):
         """Returns true if this event should be processed during a flood."""
 
+        if self._eventSourceIsDead(event):
+            return False
+
         ignore = ["object:text-changed:delete",
                   "object:text-changed:insert",
                   "object:text-changed:delete:system",
@@ -1033,7 +1078,8 @@ class EventManager:
         event.timestamp = device.event_count
         device.event_count = device.event_count + 1
 
-        if not pressed and text == "Num_Lock" and "KP_Insert" in settings.orcaModifierKeys and orca_state.activeSWcript is not None:
+        if not pressed and text == "Num_Lock" and "KP_Insert" in settings.orcaModifierKeys \
+            and orca_state.activeScript is not None:
             orca_state.activeScript.refreshKeyGrabs()
 
         if pressed:
